# Package.ONNX-Runtime-Engine-Interface

ONNX Runtime으로 Engine을 만들 때 공통으로 사용할 수 있는 Interface를 제공합니다.

## Status

[![Basic PR Check](https://github.com/404Vector/Package.ONNX-Runtime-Engine-Interface/actions/workflows/workflow_pr_check_basic.yml/badge.svg?branch=main)](https://github.com/404Vector/Package.ONNX-Runtime-Engine-Interface/actions/workflows/workflow_pr_check_basic.yml)
